@@ -8,7 +8,7 @@ class URLQueryCoder(BaseCoder):
         return '&'.join('='.join(str(k), str(v)) for k, v in data.items())
 
     def decode(self, data):
-        return urlparse.parse_qs(data)
+        return urlparse.parse_qs(data, keep_blank_values=True)
 
 class SimpleURLQueryCoder(BaseCoder):
     def encode(self, data):
@@ -16,7 +16,7 @@ class SimpleURLQueryCoder(BaseCoder):
         return '&'.join('='.join((str(k), str(v))) for k, v in data.items())
 
     def decode(self, data):
-        data = urlparse.parse_qs(data)
+        data = urlparse.parse_qs(data, keep_blank_values=True)
         for key in data:
             data[key] = data[key][0]
         return data
\ No newline at end of file
