@@ -8,12 +8,18 @@ class BaseCryptor(object):
     def decrypt_global(self, stream, secret_key):
         raise NotImplementedError
 
-    def encrypt_data(self, data, secret_key, private_key):
+    def encrypt_data(self, data, private_key, secret_key):
         raise NotImplementedError
 
-    def decrypt_data(self, data, secret_key, private_key):
+    def decrypt_data(self, data, private_key, secret_key):
         raise NotImplementedError
 
+    def decrypt_first_data(self, data, secret_key):
+        return self.decrypt_data(data, secret_key, secret_key)
+
+    def encrypt_first_data(self, data, secret_key):
+        return self.encrypt_data(data, secret_key, secret_key)
+
 class PlainCryptor(BaseCryptor):
     def encrypt_global(self, stream, secret_key):
         return stream
@@ -21,9 +27,9 @@ class PlainCryptor(BaseCryptor):
     def decrypt_global(self, stream, secret_key):
         return stream
 
-    def encrypt_data(self, data, secret_key, private_key):
+    def encrypt_data(self, data, private_key, secret_key):
         return data
 
-    def decrypt_data(self, data, secret_key, private_key):
+    def decrypt_data(self, data, private_key, secret_key):
         return data
 
